Index: test/unittests/compiler/node-test-utils.cc |
diff --git a/test/unittests/compiler/node-test-utils.cc b/test/unittests/compiler/node-test-utils.cc |
index 2f4d96d2db77febe28a946648406f05a930098fa..2feba733ce8f2e3f945c1c5d539b41f319e9e5c0 100644 |
--- a/test/unittests/compiler/node-test-utils.cc |
+++ b/test/unittests/compiler/node-test-utils.cc |
@@ -411,7 +411,7 @@ class IsConstantMatcher final : public NodeMatcher { |
class IsSelectMatcher final : public NodeMatcher { |
public: |
- IsSelectMatcher(const Matcher<MachineType>& type_matcher, |
+ IsSelectMatcher(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& value2_matcher) |
@@ -423,7 +423,7 @@ class IsSelectMatcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
*os << " whose type ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |
value0_matcher_.DescribeTo(os); |
@@ -435,19 +435,20 @@ class IsSelectMatcher final : public NodeMatcher { |
} |
bool MatchAndExplain(Node* node, MatchResultListener* listener) const final { |
- return (NodeMatcher::MatchAndExplain(node, listener) && |
- PrintMatchAndExplain(OpParameter<SelectParameters>(node).type(), |
- "type", type_matcher_, listener) && |
- PrintMatchAndExplain(NodeProperties::GetValueInput(node, 0), |
- "value0", value0_matcher_, listener) && |
- PrintMatchAndExplain(NodeProperties::GetValueInput(node, 1), |
- "value1", value1_matcher_, listener) && |
- PrintMatchAndExplain(NodeProperties::GetValueInput(node, 2), |
- "value2", value2_matcher_, listener)); |
+ return ( |
+ NodeMatcher::MatchAndExplain(node, listener) && |
+ PrintMatchAndExplain(SelectParametersOf(node->op()).representation(), |
+ "representation", type_matcher_, listener) && |
+ PrintMatchAndExplain(NodeProperties::GetValueInput(node, 0), "value0", |
+ value0_matcher_, listener) && |
+ PrintMatchAndExplain(NodeProperties::GetValueInput(node, 1), "value1", |
+ value1_matcher_, listener) && |
+ PrintMatchAndExplain(NodeProperties::GetValueInput(node, 2), "value2", |
+ value2_matcher_, listener)); |
} |
private: |
- const Matcher<MachineType> type_matcher_; |
+ const Matcher<MachineRepresentation> type_matcher_; |
const Matcher<Node*> value0_matcher_; |
const Matcher<Node*> value1_matcher_; |
const Matcher<Node*> value2_matcher_; |
@@ -456,7 +457,7 @@ class IsSelectMatcher final : public NodeMatcher { |
class IsPhiMatcher final : public NodeMatcher { |
public: |
- IsPhiMatcher(const Matcher<MachineType>& type_matcher, |
+ IsPhiMatcher(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& control_matcher) |
@@ -468,7 +469,7 @@ class IsPhiMatcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
*os << " whose type ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |
value0_matcher_.DescribeTo(os); |
@@ -481,8 +482,8 @@ class IsPhiMatcher final : public NodeMatcher { |
bool MatchAndExplain(Node* node, MatchResultListener* listener) const final { |
return (NodeMatcher::MatchAndExplain(node, listener) && |
- PrintMatchAndExplain(OpParameter<MachineType>(node), "type", |
- type_matcher_, listener) && |
+ PrintMatchAndExplain(PhiRepresentationOf(node->op()), |
+ "representation", type_matcher_, listener) && |
PrintMatchAndExplain(NodeProperties::GetValueInput(node, 0), |
"value0", value0_matcher_, listener) && |
PrintMatchAndExplain(NodeProperties::GetValueInput(node, 1), |
@@ -492,7 +493,7 @@ class IsPhiMatcher final : public NodeMatcher { |
} |
private: |
- const Matcher<MachineType> type_matcher_; |
+ const Matcher<MachineRepresentation> type_matcher_; |
const Matcher<Node*> value0_matcher_; |
const Matcher<Node*> value1_matcher_; |
const Matcher<Node*> control_matcher_; |
@@ -501,7 +502,7 @@ class IsPhiMatcher final : public NodeMatcher { |
class IsPhi2Matcher final : public NodeMatcher { |
public: |
- IsPhi2Matcher(const Matcher<MachineType>& type_matcher, |
+ IsPhi2Matcher(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& value2_matcher, |
@@ -515,7 +516,7 @@ class IsPhi2Matcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
*os << " whose type ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |
value0_matcher_.DescribeTo(os); |
@@ -530,8 +531,8 @@ class IsPhi2Matcher final : public NodeMatcher { |
bool MatchAndExplain(Node* node, MatchResultListener* listener) const final { |
return (NodeMatcher::MatchAndExplain(node, listener) && |
- PrintMatchAndExplain(OpParameter<MachineType>(node), "type", |
- type_matcher_, listener) && |
+ PrintMatchAndExplain(PhiRepresentationOf(node->op()), |
+ "representation", type_matcher_, listener) && |
PrintMatchAndExplain(NodeProperties::GetValueInput(node, 0), |
"value0", value0_matcher_, listener) && |
PrintMatchAndExplain(NodeProperties::GetValueInput(node, 1), |
@@ -543,7 +544,7 @@ class IsPhi2Matcher final : public NodeMatcher { |
} |
private: |
- const Matcher<MachineType> type_matcher_; |
+ const Matcher<MachineRepresentation> type_matcher_; |
const Matcher<Node*> value0_matcher_; |
const Matcher<Node*> value1_matcher_; |
const Matcher<Node*> value2_matcher_; |
@@ -1594,7 +1595,7 @@ Matcher<Node*> IsNumberConstant(const Matcher<double>& value_matcher) { |
} |
-Matcher<Node*> IsSelect(const Matcher<MachineType>& type_matcher, |
+Matcher<Node*> IsSelect(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& value2_matcher) { |
@@ -1603,7 +1604,7 @@ Matcher<Node*> IsSelect(const Matcher<MachineType>& type_matcher, |
} |
-Matcher<Node*> IsPhi(const Matcher<MachineType>& type_matcher, |
+Matcher<Node*> IsPhi(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& merge_matcher) { |
@@ -1612,7 +1613,7 @@ Matcher<Node*> IsPhi(const Matcher<MachineType>& type_matcher, |
} |
-Matcher<Node*> IsPhi(const Matcher<MachineType>& type_matcher, |
+Matcher<Node*> IsPhi(const Matcher<MachineRepresentation>& type_matcher, |
const Matcher<Node*>& value0_matcher, |
const Matcher<Node*>& value1_matcher, |
const Matcher<Node*>& value2_matcher, |
@@ -423,7 +423,7 @@ class IsSelectMatcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
- *os << " whose type ("; |
+ *os << " whose representation ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |
@@ -468,7 +469,7 @@ class IsPhiMatcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
- *os << " whose type ("; |
+ *os << " whose representation ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |
@@ -515,7 +516,7 @@ class IsPhi2Matcher final : public NodeMatcher { |
void DescribeTo(std::ostream* os) const final { |
NodeMatcher::DescribeTo(os); |
- *os << " whose type ("; |
+ *os << " whose representation ("; |
type_matcher_.DescribeTo(os); |
*os << "), value0 ("; |